0.3 (2019-02-25)
----------------

- Added support for long-term polynomial velocity trends.

0.2 (2018-01-21)
----------------

- Added option to specify just radial velocity to ``Barycenter`` initializer.
- Docs improvements.

0.1 (2018-01-15)
----------------

- Initial release.
